@@ -17,7 +17,6 @@
 #define HAVE_X11 __has_include(<KStartupInfo>)
 #if HAVE_X11
 #include <KStartupInfo>
-#include <KWindowInfo>
 #endif
 
 #include <KWindowSystem>
@@ -70,11 +69,6 @@ bool KateAppAdaptor::openUrl(const QString &url, const QString &encoding, bool i
     return m_app->openDocUrl(QUrl(url), encoding, isTempFile);
 }
 
-bool KateAppAdaptor::isOnActivity(const QString &activity)
-{
-    return m_app->isOnActivity(activity);
-}
-
 //-----------
 QString KateAppAdaptor::tokenOpenUrl(const QString &url, const QString &encoding)
 {
@@ -122,19 +116,12 @@ bool KateAppAdaptor::activateSession(const QString &session)
     return m_app->sessionManager()->activateSession(session);
 }
 
-int KateAppAdaptor::desktopNumber()
+qint64 KateAppAdaptor::lastActivationChange() const
 {
-#if HAVE_X11
-    if (KWindowSystem::isPlatformX11()) {
-        KWindowInfo appInfo(m_app->activeKateMainWindow()->winId(), NET::WMDesktop);
-        return appInfo.desktop();
-    }
-#endif
-
-    return 0;
+    return m_app->lastActivationChange();
 }
 
-QString KateAppAdaptor::activeSession()
+QString KateAppAdaptor::activeSession() const
 {
     return m_app->sessionManager()->activeSession()->name();
 }
